==> ejc-proother-impl-3.0.0-20220520.044213-66-sources.jar: com/ejianc/business/settle/bean/SettleDetailEntity.java <==
package com.ejianc.business.settle.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 结算明细
 *
 * @author generator
 */
@TableName("ejc_proother_settle_detail")
public class SettleDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    @TableField(value = "use_flag")
    private Integer useFlag; // 是否引用过,否-0，是-1
    @TableField(value = "settle_id")
    private Long settleId; // 结算id
    @TableField(value = "contract_id")
    private Long contractId; // 合同id
    @TableField(value = "settle_type")
    private Integer settleType; // 结算类型：0-过程，1-完工
    @TableField(value = "project_id")
    private Long projectId; // 项目Id
    @TableField(value = "settle_date")
    private Date settleDate; // 结算日期
    @TableField(value = "source_id")
    private Long sourceId; // 来源id
    @TableField(value = "source_bill_id")
    private Long sourceBillId; // 来源主单据id
    @TableField(value = "source_bill_date")
    private Date sourceBillDate; // 来源主单据日期
    @TableField(value = "source_bill_code")
    private String sourceBillCode; // 来源主单据编号
    @TableField(value = "contract_detail_id")
    private Long contractDetailId; // 合同清单id
    @TableField(value = "detail_name")
    private String detailName; // 清单名称
    @TableField(value = "detail_unit")
    private String detailUnit; // 计量单位
    @TableField(value = "detail_num")
    private BigDecimal detailNum; // 工程量
    @TableField(value = "detail_tax_rate")
    private BigDecimal detailTaxRate; // 税率
    @TableField(value = "settle_num")
    private BigDecimal settleNum; // 本期结算量
    @TableField(value = "detail_tax_price")
    private BigDecimal detailTaxPrice; // 综合单价(含税)
    @TableField(value = "detail_price")
    private BigDecimal detailPrice; // 综合单价(无税)
    @TableField(value = "settle_tax_mny")
    private BigDecimal settleTaxMny; // 本期结算金额
    @TableField(value = "settle_mny")
    private BigDecimal settleMny; // 本期结算金额(无税)
    @TableField(value = "settle_tax")
    private BigDecimal settleTax; // 本期结算税额
    @TableField(value = "source_type")
    private String sourceType; // 来源:合同内，合同外
    @TableField(value = "memo")
    private String memo; // 备注

    public Long getSettleId() {
        return settleId;
    }

    public Integer getUseFlag() {
        return useFlag;
    }

    public void setUseFlag(Integer useFlag) {
        this.useFlag = useFlag;
    }

    public void setSettleId(Long settleId) {
        this.settleId = settleId;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Integer getSettleType() {
        return settleType;
    }

    public void setSettleType(Integer settleType) {
        this.settleType = settleType;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Date getSettleDate() {
        return settleDate;
    }

    public void setSettleDate(Date settleDate) {
        this.settleDate = settleDate;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Long getSourceBillId() {
        return sourceBillId;
    }

    public void setSourceBillId(Long sourceBillId) {
        this.sourceBillId = sourceBillId;
    }

    public Date getSourceBillDate() {
        return sourceBillDate;
    }

    public void setSourceBillDate(Date sourceBillDate) {
        this.sourceBillDate = sourceBillDate;
    }

    public String getSourceBillCode() {
        return sourceBillCode;
    }

    public void setSourceBillCode(String sourceBillCode) {
        this.sourceBillCode = sourceBillCode;
    }

    public Long getContractDetailId() {
        return contractDetailId;
    }

    public void setContractDetailId(Long contractDetailId) {
        this.contractDetailId = contractDetailId;
    }

    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }

    public String getDetailUnit() {
        return detailUnit;
    }

    public void setDetailUnit(String detailUnit) {
        this.detailUnit = detailUnit;
    }

    public BigDecimal getDetailNum() {
        return detailNum;
    }

    public void setDetailNum(BigDecimal detailNum) {
        this.detailNum = detailNum;
    }

    public BigDecimal getDetailTaxRate() {
        return detailTaxRate;
    }

    public void setDetailTaxRate(BigDecimal detailTaxRate) {
        this.detailTaxRate = detailTaxRate;
    }

    public BigDecimal getSettleNum() {
        return settleNum;
    }

    public void setSettleNum(BigDecimal settleNum) {
        this.settleNum = settleNum;
    }

    public BigDecimal getDetailTaxPrice() {
        return detailTaxPrice;
    }

    public void setDetailTaxPrice(BigDecimal detailTaxPrice) {
        this.detailTaxPrice = detailTaxPrice;
    }

    public BigDecimal getDetailPrice() {
        return detailPrice;
    }

    public void setDetailPrice(BigDecimal detailPrice) {
        this.detailPrice = detailPrice;
    }

    public BigDecimal getSettleTaxMny() {
        return settleTaxMny;
    }

    public void setSettleTaxMny(BigDecimal settleTaxMny) {
        this.settleTaxMny = settleTaxMny;
    }

    public BigDecimal getSettleMny() {
        return settleMny;
    }

    public void setSettleMny(BigDecimal settleMny) {
        this.settleMny = settleMny;
    }

    public BigDecimal getSettleTax() {
        return settleTax;
    }

    public void setSettleTax(BigDecimal settleTax) {
        this.settleTax = settleTax;
    }

    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}

==> ejc-proother-impl-3.0.0-20220524.064747-89-sources.jar: com/ejianc/business/settle/bean/SettleDetailEntity.java <==
package com.ejianc.business.settle.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 结算明细
 *
 * @author generator
 */
@TableName("ejc_proother_settle_detail")
public class SettleDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    @TableField(value = "use_flag")
    private Integer useFlag; // 是否引用过,否-0，是-1
    @TableField(value = "settle_id")
    private Long settleId; // 结算id
    @TableField(value = "contract_id")
    private Long contractId; // 合同id
    @TableField(value = "settle_type")
    private Integer settleType; // 结算类型：0-过程，1-完工
    @TableField(value = "project_id")
    private Long projectId; // 项目Id
    @TableField(value = "settle_date")
    private Date settleDate; // 结算日期
    @TableField(value = "source_id")
    private Long sourceId; // 来源id
    @TableField(value = "source_bill_id")
    private Long sourceBillId; // 来源主单据id
    @TableField(value = "source_bill_date")
    private Date sourceBillDate; // 来源主单据日期
    @TableField(value = "source_bill_code")
    private String sourceBillCode; // 来源主单据编号
    @TableField(value = "contract_detail_id")
    private Long contractDetailId; // 合同清单id
    @TableField(value = "detail_name")
    private String detailName; // 清单名称
    @TableField(value = "detail_unit")
    private String detailUnit; // 计量单位
    @TableField(value = "detail_num")
    private BigDecimal detailNum; // 工程量
    @TableField(value = "detail_tax_rate")
    private BigDecimal detailTaxRate; // 税率
    @TableField(value = "settle_num")
    private BigDecimal settleNum; // 本期结算量
    @TableField(value = "detail_tax_price")
    private BigDecimal detailTaxPrice; // 综合单价(含税)
    @TableField(value = "detail_price")
    private BigDecimal detailPrice; // 综合单价(无税)
    @TableField(value = "settle_tax_mny")
    private BigDecimal settleTaxMny; // 本期结算金额
    @TableField(value = "settle_mny")
    private BigDecimal settleMny; // 本期结算金额(无税)
    @TableField(value = "settle_tax")
    private BigDecimal settleTax; // 本期结算税额
    @TableField(value = "source_type")
    private String sourceType; // 来源:合同内，合同外
    @TableField(value = "memo")
    private String memo; // 备注
    @TableField(value = "detail_wbs_id")
    private Long detailWbsId; // 核算对象主键
    @TableField(value = "detail_wbs_name")
    private String detailWbsName; // 核算对象名称
    @TableField(value = "detail_wbs_code")
    private String detailWbsCode; // 核算对象编码
    @TableField(value = "detail_subject_id")
    private Long detailSubjectId; // 成本科目主键
    @TableField(value = "detail_subject_name")
    private String detailSubjectName; // 成本科目名称
    @TableField(value = "detail_subject_code")
    private String detailSubjectCode; // 成本科目编码

    public Long getDetailWbsId() {
        return detailWbsId;
    }

    public void setDetailWbsId(Long detailWbsId) {
        this.detailWbsId = detailWbsId;
    }

    public String getDetailWbsName() {
        return detailWbsName;
    }

    public void setDetailWbsName(String detailWbsName) {
        this.detailWbsName = detailWbsName;
    }

    public String getDetailWbsCode() {
        return detailWbsCode;
    }

    public void setDetailWbsCode(String detailWbsCode) {
        this.detailWbsCode = detailWbsCode;
    }

    public Long getDetailSubjectId() {
        return detailSubjectId;
    }

    public void setDetailSubjectId(Long detailSubjectId) {
        this.detailSubjectId = detailSubjectId;
    }

    public String getDetailSubjectName() {
        return detailSubjectName;
    }

    public void setDetailSubjectName(String detailSubjectName) {
        this.detailSubjectName = detailSubjectName;
    }

    public String getDetailSubjectCode() {
        return detailSubjectCode;
    }

    public void setDetailSubjectCode(String detailSubjectCode) {
        this.detailSubjectCode = detailSubjectCode;
    }

    public Long getSettleId() {
        return settleId;
    }

    public Integer getUseFlag() {
        return useFlag;
    }

    public void setUseFlag(Integer useFlag) {
        this.useFlag = useFlag;
    }

    public void setSettleId(Long settleId) {
        this.settleId = settleId;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Integer getSettleType() {
        return settleType;
    }

    public void setSettleType(Integer settleType) {
        this.settleType = settleType;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Date getSettleDate() {
        return settleDate;
    }

    public void setSettleDate(Date settleDate) {
        this.settleDate = settleDate;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Long getSourceBillId() {
        return sourceBillId;
    }

    public void setSourceBillId(Long sourceBillId) {
        this.sourceBillId = sourceBillId;
    }

    public Date getSourceBillDate() {
        return sourceBillDate;
    }

    public void setSourceBillDate(Date sourceBillDate) {
        this.sourceBillDate = sourceBillDate;
    }

    public String getSourceBillCode() {
        return sourceBillCode;
    }

    public void setSourceBillCode(String sourceBillCode) {
        this.sourceBillCode = sourceBillCode;
    }

    public Long getContractDetailId() {
        return contractDetailId;
    }

    public void setContractDetailId(Long contractDetailId) {
        this.contractDetailId = contractDetailId;
    }

    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }

    public String getDetailUnit() {
        return detailUnit;
    }

    public void setDetailUnit(String detailUnit) {
        this.detailUnit = detailUnit;
    }

    public BigDecimal getDetailNum() {
        return detailNum;
    }

    public void setDetailNum(BigDecimal detailNum) {
        this.detailNum = detailNum;
    }

    public BigDecimal getDetailTaxRate() {
        return detailTaxRate;
    }

    public void setDetailTaxRate(BigDecimal detailTaxRate) {
        this.detailTaxRate = detailTaxRate;
    }

    public BigDecimal getSettleNum() {
        return settleNum;
    }

    public void setSettleNum(BigDecimal settleNum) {
        this.settleNum = settleNum;
    }

    public BigDecimal getDetailTaxPrice() {
        return detailTaxPrice;
    }

    public void setDetailTaxPrice(BigDecimal detailTaxPrice) {
        this.detailTaxPrice = detailTaxPrice;
    }

    public BigDecimal getDetailPrice() {
        return detailPrice;
    }

    public void setDetailPrice(BigDecimal detailPrice) {
        this.detailPrice = detailPrice;
    }

    public BigDecimal getSettleTaxMny() {
        return settleTaxMny;
    }

    public void setSettleTaxMny(BigDecimal settleTaxMny) {
        this.settleTaxMny = settleTaxMny;
    }

    public BigDecimal getSettleMny() {
        return settleMny;
    }

    public void setSettleMny(BigDecimal settleMny) {
        this.settleMny = settleMny;
    }

    public BigDecimal getSettleTax() {
        return settleTax;
    }

    public void setSettleTax(BigDecimal settleTax) {
        this.settleTax = settleTax;
    }

    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}
